<?php
/**
 * Configuration class
 *
 * @package faq-accordion-block
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Configuration class
 */
class WDPFAB_Config {

	/**
	 * Return default configuration
	 */
	public static function get_all() {

		return array(
			'padding'                  => array(
				'name'  => __( 'Padding', 'faq-accordion-block' ),
				'value' => apply_filters( 'wdpfab_default_padding', 17 ),
				'type'  => 'range',
				'min'   => 0,
				'max'   => 120,
				'step'  => 1,
			),
			'border-width'             => array(
				'name'  => __( 'Border width', 'faq-accordion-block' ),
				'value' => apply_filters( 'wdpfab_default_border_width', 1 ),
				'type'  => 'range',
				'min'   => 0,
				'max'   => 30,
			),
			'border-style'             => array(
				'name'   => __( 'Border style', 'faq-accordion-block' ),
				'value'  => apply_filters( 'wdpfab_default_border_style', 'solid' ),
				'type'   => 'select',
				'values' => array(
					'solid'  => __( 'Solid', 'faq-accordion-block' ),
					'dashed' => __( 'Dashed', 'faq-accordion-block' ),
					'dotted' => __( 'Dotted', 'faq-accordion-block' ),
				),
			),
			'border-color'             => array(
				'name'  => __( 'Border color', 'faq-accordion-block' ),
				'value' => apply_filters( 'wdpfab_default_border_color', '#ddd' ),
				'type'  => 'color',
			),
			'border-color-hover'       => array(
				'name'  => __( 'Border color (on hover)', 'faq-accordion-block' ),
				'value' => apply_filters( 'wdpfab_default_border_color_hover', '#ddd' ),
				'type'  => 'color',
			),
			'border-radius'            => array(
				'name'  => __( 'Border radius', 'faq-accordion-block' ),
				'value' => apply_filters( 'wdpfab_default_border_radius', 2 ),
				'type'  => 'range',
				'min'   => 0,
				'max'   => 50,
			),
			'background-color'         => array(
				'name'  => __( 'Background color', 'faq-accordion-block' ),
				'value' => apply_filters( 'wdpfab_default_background_color', '#fff' ),
				'type'  => 'color',
			),
			'background-color-hover'   => array(
				'name'  => __( 'Background color (on hover)', 'faq-accordion-block' ),
				'value' => apply_filters( 'wdpfab_default_background_color_hover', '#fff' ),
				'type'  => 'color',
			),
			'box-shadow-x-offset'      => array(
				'name'  => __( 'Box shadow X offset', 'faq-accordion-block' ),
				'value' => apply_filters( 'wdpfab_default_box_shadow_x_offset', 0 ),
				'type'  => 'range',
				'min'   => -100,
				'max'   => 100,
				'step'  => 1,
			),
			'box-shadow-y-offset'      => array(
				'name'  => __( 'Box shadow Y offset', 'faq-accordion-block' ),
				'value' => apply_filters( 'wdpfab_default_box_shadow_y_offset', 0 ),
				'type'  => 'range',
				'min'   => -100,
				'max'   => 100,
				'step'  => 1,
			),
			'box-shadow-blur-radius'   => array(
				'name'  => __( 'Box shadow blur radius', 'faq-accordion-block' ),
				'value' => apply_filters( 'wdpfab_default_box_shadow_blur_radius', 35 ),
				'type'  => 'range',
				'min'   => 0,
				'max'   => 100,
				'step'  => 1,
			),
			'box-shadow-spread-radius' => array(
				'name'  => __( 'Box shadow spread radius', 'faq-accordion-block' ),
				'value' => apply_filters( 'wdpfab_default_box_shadow_spread_radius', 0 ),
				'type'  => 'range',
				'min'   => -100,
				'max'   => 100,
				'step'  => 1,
			),
			'box-shadow-color'         => array(
				'name'  => __( 'Box shadow color', 'faq-accordion-block' ),
				'value' => apply_filters( 'wdpfab_default_box_shadow_color', '#000' ),
				'type'  => 'color',
			),
			'box-shadow-opacity'       => array(
				'name'  => __( 'Box shadow opacity', 'faq-accordion-block' ),
				'value' => apply_filters( 'wdpfab_default_box_shadow_opacity', 0.2 ),
				'type'  => 'range',
				'min'   => 0,
				'max'   => 1,
				'step'  => 0.01,
			),
		);
	}

	/**
	 * Get key-value of default config
	 */
	public static function get_simplified() {

		$result = array();

		foreach ( self::get_all() as $key => $data ) {
			$result[ $key ] = $data['value'];
		}

		return $result;
	}
}
