<?php
/**
 * Enqueue block scripts and styles
 *
 * @package faq-accordion-block
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

add_action( 'enqueue_block_editor_assets', array( 'WDPFAB_Enqueue', 'editor_enqueue' ) );
add_action( 'wp_enqueue_scripts', array( 'WDPFAB_Enqueue', 'enqueue_block' ) );

/**
 * Enqueue class
 */
class WDPFAB_Enqueue {

	/**
	 * Enqueue scripts and styles on editor
	 */
	public static function editor_enqueue() {

		wp_enqueue_script(
			'wdp/faq-accordion-block',
			plugins_url( 'build/block.min.js', WDPFAB_MAIN_FILE ),
			array(
				'wp-i18n',
				'wp-blocks',
				'wp-editor',
				'wp-components',
				'wp-element',
			),
			WDPFAB_VERSION,
			true
		);

		wp_localize_script(
			'wdp/faq-accordion-block',
			'wdpfab',
			array_merge(
				self::get_default_block_styles(),
				array(
					'themeColors' => current( (array) get_theme_support( 'editor-color-palette' ) ),
				)
			)
		);

		self::enqueue_block( true );
	}

	/**
	 * Enqueue FAQ Accordion Block styles on front-end
	 *
	 * @param bool $is_editor Are styles for editor or not.
	 */
	public static function enqueue_block( $is_editor = false ) {

		if ( empty( $is_editor ) ) {
			$is_editor = false;
		}

		wp_enqueue_style(
			'wdp/faq-accordion-block',
			plugins_url( 'build/block' . esc_attr( true === $is_editor ? '-editor' : '' ) . '.css', WDPFAB_MAIN_FILE ),
			array(),
			WDPFAB_VERSION
		);

		wp_add_inline_style(
			'wdp/faq-accordion-block',
			self::generate_css()
		);

		if ( false === $is_editor ) {

			wp_enqueue_script(
				'wdp/faq-accordion-block-slide-toggle',
				plugins_url( 'build/slide-toggle.min.js', WDPFAB_MAIN_FILE ),
				array(),
				WDPFAB_VERSION,
				true
			);
		}
	}

	/**
	 * Get default block styles
	 */
	public static function get_default_block_styles() {

		$defaults = WDPFAB_Config::get_simplified();
		$result   = array();

		foreach ( $defaults as $key => $value ) {

			$key             = explode( '-', $key );
			$key_parts_count = count( $key );

			for ( $i = 1; $i < $key_parts_count; $i++ ) {
				$key[ $i ] = ucfirst( $key[ $i ] );
			}

			$result[ implode( '', $key ) ] = $value;
		}

		return $result;
	}

	/**
	 * Generate CSS variables
	 */
	public static function generate_css() {

		$defaults = WDPFAB_Config::get_simplified();
		$css      = '';
		$vars     = array(
			'--wdpfab-padding'                 => esc_attr( $defaults['padding'] ) . 'px',
			'--wdpfab-border-width'            => esc_attr( $defaults['border-width'] ) . 'px',
			'--wdpfab-border-radius'           => esc_attr( $defaults['border-radius'] ) . 'px',
			'--wdpfab-border-style'            => esc_attr( $defaults['border-style'] ),
			'--wdpfab-border-color'            => esc_attr( $defaults['border-color'] ),
			'--wdpfab-border-color-hover'      => esc_attr( $defaults['border-color-hover'] ),
			'--wdpfab-background-color'        => esc_attr( $defaults['background-color'] ),
			'--wdpfab-background-color-hover'  => esc_attr( $defaults['background-color-hover'] ),
			'--wdpfab-box-shadow-xoffset'      => esc_attr( $defaults['box-shadow-x-offset'] ) . 'px',
			'--wdpfab-box-shadow-yoffset'      => esc_attr( $defaults['box-shadow-y-offset'] ) . 'px',
			'--wdpfab-box-shadow-blurradius'   => esc_attr( $defaults['box-shadow-blur-radius'] ) . 'px',
			'--wdpfab-box-shadow-spreadradius' => esc_attr( $defaults['box-shadow-spread-radius'] ) . 'px',
			'--wdpfab-box-shadow-color'        => esc_attr( self::hex2rgb( $defaults['box-shadow-color'], $defaults['box-shadow-opacity'] ) ),
		);

		foreach ( $vars as $var => $value ) {
			$css .= $var . ':' . $value . ';';
		}

		return ':root{' . esc_attr( $css ) . '}';
	}

	/**
	 * Transform HEX to RGB
	 *
	 * @param string $hex     HEX color.
	 * @param int    $opacity Color opacity value.
	 */
	public static function hex2rgb( $hex, $opacity ) {

		( strlen( $hex ) === 4 ) ? list( $r, $g, $b ) = sscanf( $hex, '#%1x%1x%1x' ) : list( $r, $g, $b ) = sscanf( $hex, '#%2x%2x%2x' );
		return "rgba($r,$g,$b,$opacity)";
	}
}
